@@ -174,5 +174,9 @@
 #define SYS_query_module	167
 #define SYS_poll		168
 #define SYS_syscall_poll	SYS_poll
+#define SYS_nfsservctl		169
+#define SYS_setresgid		170
+#define SYS_getresgid		171
+#define SYS_prctl		172
 
 #endif	/* <sys/syscall.h> */
