@@ -22,7 +22,7 @@ domain (long double x)
     if (x < 0.L)
        return __infnanl( EDOM);
     else /* i.e. x== 0. */
-      return __infnanl( ERANGE);
+      return __infnanl(-ERANGE);
 }
 
 long double
